﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Core.Primitives;

namespace UltraChartColumnWithScatterChart
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            manufacturingUltraChart.CompositeChart.ChartLayers.Clear();
            manufacturingUltraChart.CompositeChart.Series.Clear();
            manufacturingUltraChart.CompositeChart.Legends.Clear();

            manufacturingUltraChart.TitleTop.Text = "Charge de travail de fabrication pour la période du ";// +_FirstDateValue.ToShortDateString() + " au " + _LastDateValue.ToShortDateString();
            manufacturingUltraChart.TitleBottom.Text = "Généré le: " + DateTime.Now.ToShortDateString();

            //Build a datatable with the desired columns
            DataTable workloadTable = new DataTable();
            workloadTable.Columns.Add("Semaine", typeof(string));        //Weekly datetimes
            workloadTable.Columns.Add("HrsFabDispo", typeof(decimal));  //Manufacturing available hours --> Column layer
            workloadTable.Columns.Add("HrsFabPlanif", typeof(decimal)); //Manufacturing planned hours --> Scatter layer
            workloadTable.Columns.Add("SemaineCount", typeof(int));     //Counter for weekly datetimes to use as x axis for scatter layer

            int weekCounter = 0;

            //Fill the table from a custom weekly workload datatable
            Random rnd = new Random();
            for (int k = 0; k < 50; k++)
            {
                weekCounter = weekCounter + 1; //Week counter for use on X2 axis with scatter layer
                workloadTable.Rows.Add(new Object[] { DateTime.Today.AddDays(k).ToString(), rnd.Next(-2500, 2500), rnd.Next(0, 1000), weekCounter });
            }

            //foreach (DAL.UniDataAdapters.PlanifIntegree.CapaciteProd.ChargeTravailHebdoGlobaleRow dataRow in _ChargeTravailHebdoTable)
            //{
            //    weekCounter = weekCounter + 1; //Week counter for use on X2 axis with scatter layer
            //    workloadTable.Rows.Add(new Object[] { dataRow.Semaine.ToShortDateString(), dataRow.HrsDispoFab, dataRow.HrsPlanifFabSavStock, weekCounter });
            //}

            //Composite chart type containing 2 layers
            manufacturingUltraChart.ChartType = ChartType.Composite;
            ChartArea myChartArea = new ChartArea();
            manufacturingUltraChart.CompositeChart.ChartAreas.Add(myChartArea);

            //First X axis to be used with the column chart (series A)
            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.DataType = AxisDataType.String;
            axisX.SetLabelAxisType = SetLabelAxisType.GroupBySeries;
            axisX.Labels.ItemFormatString = "<ITEM_LABEL>";
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.Extent = 150;

            //Y axis to be used with both layers
            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";
            axisY.RangeType = AxisRangeType.Custom;
            //Set the y axis margin to see all values
            axisY.RangeMin = -2500;// Convert.ToDouble(manufacturingChartYAxisMinValue);
            axisY.RangeMax = 2500;// Convert.ToDouble(manufacturingChartYAxisMaxValue);

            //Axis 2 to support the scatter layer with numeric data
            AxisItem axisX2 = new AxisItem();
            axisX2.OrientationType = AxisNumber.X2_Axis;
            axisX2.DataType = AxisDataType.Numeric;
            axisX2.SetLabelAxisType = SetLabelAxisType.GroupBySeries;

            //Add the axes to the chart area
            myChartArea.Axes.Add(axisX);
            myChartArea.Axes.Add(axisY);
            myChartArea.Axes.Add(axisX2);

            //First serie to display available manufacturing hours in a "column chart"
            NumericSeries seriesA = new NumericSeries();
            seriesA.Label = "HRS FAB DISPONIBLES";
            seriesA.Data.DataSource = workloadTable;
            seriesA.Data.LabelColumn = "Semaine";
            seriesA.Data.ValueColumn = "HrsFabDispo";
            seriesA.PEs.Add(new PaintElement(Color.Transparent));

            //Second serie to display planned manufacturing hours in a XY series (dotted line on a scatter layer)
            XYSeries seriesB = new XYSeries();
            seriesB.Label = "HRS PLANIF FAB/SAV/STOCK";
            seriesB.Data.DataSource = workloadTable;
            seriesB.Data.LabelColumn = "Semaine";
            seriesB.Data.ValueXColumn = "SemaineCount";
            seriesB.Data.ValueYColumn = "HrsFabPlanif";
            seriesB.PEs.Add(new PaintElement(Color.Red));

            //Add the series to the chart
            manufacturingUltraChart.CompositeChart.Series.Add(seriesA);
            manufacturingUltraChart.CompositeChart.Series.Add(seriesB);

            //Add a layer for the column chart
            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ColumnChart;
            myColumnLayer.ChartArea = myChartArea;
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            myColumnLayer.Series.Add(seriesA);

            //Add a layer for the scatter chart
            ChartLayerAppearance myScatterLayer = new ChartLayerAppearance();
            myScatterLayer.ChartType = ChartType.ScatterChart;
            ((ScatterChartAppearance)myScatterLayer.ChartTypeAppearance).ConnectWithLines =
              true;
            myScatterLayer.ChartArea = myChartArea;
            myScatterLayer.AxisX = axisX2;
            myScatterLayer.AxisY = axisY;
            myScatterLayer.Series.Add(seriesB);

            //Add the layers to the chart
            manufacturingUltraChart.CompositeChart.ChartLayers.Add(myColumnLayer);
            manufacturingUltraChart.CompositeChart.ChartLayers.Add(myScatterLayer);

            //Add a legend for the scatter layer (planned manufacturing hours)
            CompositeLegend myLegend = new CompositeLegend();
            myLegend.ChartLayers.Add(myScatterLayer);
            myLegend.Bounds = new Rectangle(90, 0, 10, 5);
            myLegend.BoundsMeasureType = MeasureType.Percentage;
            myLegend.PE.ElementType = PaintElementType.Gradient;
            myLegend.PE.FillGradientStyle = GradientStyle.ForwardDiagonal;
            myLegend.PE.Fill = Color.CornflowerBlue;
            myLegend.PE.FillStopColor = Color.Transparent;
            myLegend.Border.CornerRadius = 10;
            myLegend.Border.Thickness = 0;
            manufacturingUltraChart.CompositeChart.Legends.Add(myLegend);


            //Set the chart datasource, and databind
           //manufacturingUltraChart.DataSource = workloadTable;
           // manufacturingUltraChart.Data.DataBind();


        }

        private void manufacturingUltraChart_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {
            List<Box> listBox = new List<Box>();
            foreach (Primitive item in e.SceneGraph)
            {
                Box pl = item as Box;
                if (pl != null && pl.Series != null) listBox.Add(pl);

                Polyline line = item as Polyline;
                if (line != null)
                {
                    int k = 0;
                    foreach (DataPoint pp in line.points)
                    {
                        pp.point.X = listBox[k].rect.X + (listBox[k].rect.Width / 2);
                        k++;
                    }
                }
            }
        }
    }
}
